X-Git-Url: http://git.sameswireless.fr/l2tpns.git/blobdiff_plain/abbc5c5fcef36f53fe0367d4f0877c1f3c05ff90..b02fdbcde70dc5bee0a4f0edb86f7ffe0b5a2a3b:/l2tpns.h?ds=inline

diff --git a/l2tpns.h b/l2tpns.h
index 8e416e6..0262ac6 100644
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.16 2004-08-26 04:44:26 fred_nerk Exp $
+// $Id: l2tpns.h,v 1.33 2004-11-11 03:07:43 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -15,7 +15,7 @@
 #include <sys/types.h>
 #include <libcli.h>
 
-#define VERSION	"2.0.1"
+#define VERSION	"2.0.6"
 
 // Limits
 #define MAXTUNNEL	500		// could be up to 65535
@@ -24,7 +24,7 @@
 
 #define RADIUS_SHIFT	5
 #define RADIUS_MASK	((unsigned short)(((unsigned short)~0) >> (16 - RADIUS_SHIFT)))
-#define	MAXRADIUS	((2 << (RADIUS_SHIFT - 1)) * 255)
+#define	MAXRADIUS	((unsigned long)(1L << RADIUS_SHIFT) * 255)
 
 #define T_UNDEF		(0xffff)	// A tunnel ID that won't ever be used. Mark session as undefined.
 #define T_FREE		(0)		// A tunnel ID that won't ever be used. Mark session as free.
@@ -40,26 +40,37 @@
 #define MAX_LOG_LENGTH	512		// Maximum size of log message
 #define ECHO_TIMEOUT	60		// Time between last packet sent and LCP ECHO generation
 #define IDLE_TIMEOUT	240		// Time between last packet sent and LCP ECHO generation
-#define BUSY_WAIT_TIMEOUT	3000	// 5 minutes in 1/10th seconds to wait for radius to cleanup on shutdown
+#define BUSY_WAIT_TIME	3000		// 5 minutes in 1/10th seconds to wait for radius to cleanup on shutdown
 
 // Constants
-#include "config.h"
-#ifndef PLUGINDIR
-#define PLUGINDIR	LIBDIR			// Plugins
+#ifndef ETCDIR
+#define ETCDIR		"/etc/l2tpns"
 #endif
 
-#ifndef PLUGINCONF
-#define PLUGINCONF	ETCDIR			// Plugin config dir
+#ifndef LIBDIR
+#define LIBDIR		"/usr/lib/l2tpns"
 #endif
 
-#ifndef DATADIR
-#define DATADIR		"/tmp"
+#ifndef STATEDIR
+#define STATEDIR	"/var/lib/l2tpns"
+#endif
+
+#ifndef PLUGINDIR
+#define PLUGINDIR	LIBDIR		// Plugins
+#endif
+
+#ifndef PLUGINCONF
+#define PLUGINCONF	ETCDIR		// Plugin config dir
 #endif
 
 #ifndef FLASHDIR
 #define FLASHDIR	ETCDIR
 #endif
 
+#ifndef DATADIR
+#define DATADIR		STATEDIR
+#endif
+
 #define TUNDEVICE	"/dev/net/tun"
 #define STATEFILE	DATADIR "/state.dump"		// State dump file
 #define CONFIGFILE	FLASHDIR "/startup-config"	// Configuration file
@@ -111,7 +122,8 @@ struct cli_session_actions {
 	char action;
 	ipt snoop_ip;
 	u16 snoop_port;
-	int throttle;
+	int throttle_in;
+	int throttle_out;
 };
 
 #define CLI_SESS_KILL		0x01
@@ -149,10 +161,10 @@ typedef struct sessions
 {
 	sessionidt next;		// next session in linked list
 	sessionidt far;			// far end session ID
-	tunnelidt tunnel;		// tunnel ID
+	tunnelidt tunnel;		// near end tunnel ID
 	ipt ip;				// IP of session set by RADIUS response (host byte order).
 	int ip_pool_index;		// index to IP pool
-	unsigned long sid;		// session id for hsddb
+	unsigned long unique_id;	// unique session id
 	u16 nr;				// next receive
 	u16 ns;				// next send
 	u32 magic;			// ppp magic number
@@ -161,7 +173,8 @@ typedef struct sessions
 	u32 total_cin;			// This counter is never reset while a session is open
 	u32 total_cout;			// This counter is never reset while a session is open
 	u32 id;				// session id
-	u32 throttle;			// non-zero if this session is throttled.
+	u16 throttle_in;		// upstream throttle rate (kbps)
+	u16 throttle_out;		// downstream throttle rate
 	clockt opened;			// when started
 	clockt die;			// being closed, when to finally free
 	time_t last_packet;		// Last packet from the user (used for idle timeouts)
@@ -172,6 +185,7 @@ typedef struct sessions
 	u16 tbf_in;			// filter bucket for throttling in from the user.
 	u16 tbf_out;			// filter bucket for throttling out to the user.
 	u8 l2tp_flags;			// various bit flags from the ICCN on the l2tp tunnel.
+	u8 reserved_old_snoop;		// No longer used - remove at some time
 	u8 walled_garden;		// is this session gardened?
 	u8 flags1;			// additional flags (currently unused);
 	char random_vector[MAXTEL];
@@ -184,20 +198,21 @@ typedef struct sessions
 	u32 flags;			// Various session flags.
 	ipt snoop_ip;			// Interception destination IP
 	u16 snoop_port;			// Interception destination port
-	char reserved[28];		// Space to expand structure without changing HB_VERSION
+	u16 sid;			// near end session id.
+	char reserved[20];		// Space to expand structure without changing HB_VERSION
 }
 sessiont;
 
-#define SF_IPCP_ACKED	(1<<0)		// Has this session seen an IPCP Ack?
+#define SF_IPCP_ACKED	1	// Has this session seen an IPCP Ack?
+#define SF_LCP_ACKED	2	// LCP negotiated
 
 typedef struct {
 	u32	cin;
 	u32	cout;
 } sessioncountt;
 
-#define	SESSIONPFC	1            // PFC negotiated flags
-#define	SESSIONACFC	2           // ACFC negotiated flags
-#define SESSIONLCPACK	4	// LCP negotiated
+#define	SESSIONPFC	1	// PFC negotiated flags
+#define	SESSIONACFC	2	// ACFC negotiated flags
 
 // 168 bytes per tunnel
 typedef struct tunnels
@@ -406,10 +421,13 @@ struct configt
 
 	ipt		default_dns1, default_dns2;
 
-	unsigned long	rl_rate;
+	unsigned long	rl_rate;			// default throttle rate
+	int		num_tbfs;			// number of throttle buckets
+
 	int		save_state;
 	char		accounting_dir[128];
 	ipt		bind_address;
+	ipt		peer_address;
 	int		send_garp;			// Set to true to garp for vip address on startup
 
 	int		target_uid;
@@ -442,18 +460,24 @@ struct configt
 	int		cluster_hb_timeout;		// How many missed heartbeats trigger an election.
 
 #ifdef BGP
+#define BGP_NUM_PEERS	2
 	u16		as_number;
-	char		bgp_peer[2][64];
-	u16		bgp_peer_as[2];
+	struct {
+		char	name[64];
+	    	u16	as;
+		int	keepalive;
+		int	hold;
+	}		neighbour[BGP_NUM_PEERS];
 #endif
 };
 
+enum config_typet { INT, STRING, UNSIGNED_LONG, SHORT, BOOL, IP, MAC };
 struct config_descriptt
 {
 	char *key;
 	int offset;
 	int size;
-	enum { INT, STRING, UNSIGNED_LONG, SHORT, BOOL, IP } type;
+	enum config_typet type;
 };
 
 // arp.c
@@ -482,17 +506,6 @@ void radiusretry(u16 r);
 u16 radiusnew(sessionidt s);
 void radiusclear(u16 r, sessionidt s);
 
-// throttle.c
-int throttle_session(sessionidt s, int throttle);
-
-
-// rl.c
-void init_rl();
-u16 rl_create_tbf();
-u16 rl_get_tbf();
-void rl_done_tbf(u16 t);
-void rl_destroy_tbf(u16 t);
-
 
 // l2tpns.c
 clockt now(void);
@@ -500,7 +513,7 @@ clockt backoff(u8 try);
 void routeset(sessionidt, ipt ip, ipt mask, ipt gw, u8 add);
 void inittun(void);
 void initudp(void);
-void initdata(void);
+void initdata(int optdebug, char *optconfig);
 void initippool();
 sessionidt sessionbyip(ipt ip);
 sessionidt sessionbyuser(char *username);
@@ -533,12 +546,14 @@ int cmd_show_ipcache(struct cli_def *cli, char *command, char **argv, int argc);
 int cmd_show_hist_idle(struct cli_def *cli, char *command, char **argv, int argc);
 int cmd_show_hist_open(struct cli_def *cli, char *command, char **argv, int argc);
 
-#define log _log
-#ifndef log_hex
-#define log_hex(a,b,c,d) do{if (a <= config->debug) _log_hex(a,0,0,0,b,c,d);}while (0)
-#endif
+#undef LOG
+#undef LOG_HEX
+#define LOG(D, a, s, t, f, ...)	({ if (D <= config->debug) _log(D, a, s, t, f, ## __VA_ARGS__); })
+#define LOG_HEX(D, t, d, s)	({ if (D <= config->debug) _log_hex(D, t, d, s); })
+
 void _log(int level, ipt address, sessionidt s, tunnelidt t, const char *format, ...) __attribute__((format (printf, 5, 6)));
-void _log_hex(int level, ipt address, sessionidt s, tunnelidt t, const char *title, const char *data, int maxsize);
+void _log_hex(int level, const char *title, const char *data, int maxsize);
+
 void build_chap_response(char *challenge, u8 id, u16 challenge_length, char **challenge_response);
 int sessionsetup(tunnelidt t, sessionidt s);
 int cluster_send_session(int s);
@@ -561,7 +576,7 @@ void host_unreachable(ipt destination, u16 id, ipt source, char *packet, int pac
 void fix_address_pool(int sid);
 void rebuild_address_pool(void);
 void send_ipin(sessionidt s, u8 * buf, int len);
-int throttle_session(sessionidt s, int throttle);
+void throttle_session(sessionidt s, int rate_in, int rate_out);
 int load_session(sessionidt, sessiont *);
 void become_master(void);	// We're the master; kick off any required master initializations.
 extern tunnelt *tunnel;
@@ -575,12 +590,12 @@ if (count++ < max) { \
 	void *array[20]; \
 	char **strings; \
 	int size, i; \
-	log(0, 0, 0, t, "Backtrace follows"); \
+	LOG(0, 0, 0, t, "Backtrace follows"); \
 	size = backtrace(array, 10); \
 	strings = backtrace_symbols(array, size); \
 	if (strings) for (i = 0; i < size; i++) \
 	{ \
-		log(0, 0, 0, t, "%s\n", strings[i]); \
+		LOG(0, 0, 0, t, "%s\n", strings[i]); \
 	} \
 	free(strings); \
 }
@@ -589,10 +604,11 @@ if (count++ < max) { \
 extern struct configt *config;
 extern time_t basetime;		// Time when this process started.
 extern time_t time_now;		// Seconds since EPOCH.
-extern u32 last_sid;
+extern u32 last_id;
 extern struct Tstats *_statistics;
 extern ipt my_address;
 extern int tun_write(u8 *data, int size);
+extern int clifd;
 
 
 #define TIME (config->current_time)